@@ -20,9 +20,8 @@
 
 ================================================================================
 
-	The LilyPond module provides some methods to help you generate files
-	in the LilyPond format. This allows you to create sheet music from some of 
-	the objects in mingus.containers
+	The !LilyPond module provides some methods to help you generate files
+	in the !LilyPond format. This allows you to create sheet music from some of the objects in mingus.containers
 
 ================================================================================
 
@@ -30,10 +29,12 @@
 
 from mingus.containers.Note import Note
 from mingus.containers.mt_exceptions import NoteFormatError, UnexpectedObjectError
+import os
 
 def from_Note(note, process_octaves = True):
-	"""Expects a Note object and returns the LilyPond equivalent
-	in a string"""
+	"""Expects a [refMingusContainersNote Note] object and returns \
+the !LilyPond equivalent in a string. If process_octaves is set to False, \
+all data regarding octaves will be ignored."""
 	# Throw exception
 	if not( hasattr(note, "name")):
 		return False
@@ -62,9 +63,9 @@ def from_Note(note, process_octaves = True):
 	return result
 
 def from_NoteContainer(nc, duration = None):
-	"""Expects a NoteContainer object and returns the LilyPond 
-	equivalent in a string. The second argument determining the 
-	duration of the NoteContainer is optional."""
+	"""Expects a [refMingusContainersNotecontainer NoteContainer] object \
+and returns the !LilyPond equivalent in a string. The second argument \
+determining the duration of the NoteContainer is optional."""
 
 	# Throw exception
 	if not ( hasattr ( nc, "notes" ) ):
@@ -92,9 +93,9 @@ def from_NoteContainer(nc, duration = None):
 		return result
 
 def from_Bar(bar, showkey = True, showtime = True):
-	"""Expects a Bar object and returns the LilyPond equivalent
-	in a string. showkey and showtime can be set to determine whether
-	the key and the time should be shown."""
+	"""Expects a [refMingusContainersBar Bar] object and returns the \
+!LilyPond equivalent in a string. showkey and showtime can be set to \
+determine whether the key and the time should be shown."""
 	# Throw exception
 	if not ( hasattr ( bar , "bar" ) ):
 		return False
@@ -119,8 +120,8 @@ def from_Bar(bar, showkey = True, showtime = True):
 	
 
 def from_Track(track):
-	"""Processes a Track object and returns the Lilypond equivalent
-	in a string."""
+	"""Processes a [refMingusContainersTrack Track] object and returns \
+the Lilypond equivalent in a string."""
 	# Throw exception
 	if not ( hasattr ( track, "bars" ) ):
 		return False
@@ -147,13 +148,13 @@ def from_Track(track):
 
 
 def from_Composition(composition):
-	"""Get's the LilyPond equivalent of a Composition in a string"""
-	# Throw exception
+	"""Returns the !LilyPond equivalent of a \
+[refMingusContainersComposition Composition] in a string"""
+	#warning Throw exception
 	if not ( hasattr ( composition, "tracks" ) ):
 		return False
 
-	result = "\\version 2.10.33 "
-	result += "\\header { title = \"%s\" composer = \"%s\" opus = \"%s\" } "\
+	result = "\\header { title = \"%s\" composer = \"%s\" opus = \"%s\" } "\
 				% (composition.title, composition.author, composition.subtitle)
 	for track in composition.tracks:
 		result += from_Track(track) + " "
@@ -162,3 +163,30 @@ def from_Composition(composition):
 
 def from_Suite(suite):
 	pass
+
+
+def to_png(ly_string, filename):
+	"""Saves a string in LilyPonds format to a PNG. Needs LilyPond in the \
+$PATH."""
+	return save_string_and_execute_LilyPond(ly_string, filename, "-fpng")
+
+def to_pdf(ly_string, filename):
+	"""Saves a string in LilyPonds format to a PDF. Needs LilyPond in the \
+$PATH."""
+	return save_string_and_execute_LilyPond(ly_string, filename, "-fpdf")
+
+def save_string_and_execute_LilyPond(ly_string, filename, command):
+	"""A helper function for to_png and to_pdf. Should not be used directly"""
+	ly_string = "\\version \"2.10.33\"\n" + ly_string
+	try:
+		f = open(filename + ".ly", 'w')
+		f.write(ly_string)
+		f.close()
+	except:
+		return False
+	command = "lilypond " + command + " -o " + filename + " " + filename + ".ly"
+	print "Executing: %s" % command
+	os.system(command)
+	os.remove(filename + ".ly")
+	return True
+
